==> matrix_sdk-0.3.0.tar.gz: lib/src/event/room/state/name_change_event.dart <==
// Copyright (C) 2019  Wilko Manger
//
// This file is part of matrix-dart-sdk.
//
// matrix-dart-sdk is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// matrix-dart-sdk is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public License
// along with matrix-dart-sdk.  If not, see <https://www.gnu.org/licenses/>.

import 'package:matrix_sdk/src/event/room/state/state_event.dart';
import 'package:matrix_sdk/src/identifier.dart';
import 'package:matrix_sdk/src/room/room.dart';
import 'package:matrix_sdk/src/user.dart';
import 'package:meta/meta.dart';

const String _nameChangeEventType = 'm.room.name';

class NameChangeEvent extends StateEvent {
  static const String type = _nameChangeEventType;

  @override
  final String matrixType = type;

  @override
  final NameChange content;

  NameChangeEvent(
      this.content, EventId id, Room room, User sender, DateTime time)
      : super(id, room, sender, time, stateKey: '');

  factory NameChangeEvent.fromJson(
      EventId id, Room room, User sender,
      DateTime time, dynamic json) {
    var name = json['content']['name'];
    return NameChangeEvent(NameChange(name: name), id, room, sender, time);
  }
}

class NameChange extends StateEventContent {
  @override
  final String matrixType = _nameChangeEventType;

  final String name;

  NameChange({@required this.name});

  @override
  Map<String, dynamic> toJson() => super.toJson()
    ..addAll({
      'name': name
    });
}

==> matrix_sdk-0.4.6.tar.gz: lib/src/event/room/state/name_change_event.dart <==
// Copyright (C) 2019  Wilko Manger
//
// This file is part of matrix-dart-sdk.
//
// matrix-dart-sdk is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// matrix-dart-sdk is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public License
// along with matrix-dart-sdk.  If not, see <https://www.gnu.org/licenses/>.

import 'package:matrix_sdk/src/event/event.dart';
import 'package:matrix_sdk/src/event/room/state/state_event.dart';
import 'package:matrix_sdk/src/identifier.dart';
import 'package:matrix_sdk/src/room/room.dart';
import 'package:matrix_sdk/src/user.dart';
import 'package:meta/meta.dart';

const String _nameChangeEventType = 'm.room.name';

class NameChangeEvent extends StateEvent {
  static const String type = _nameChangeEventType;

  @override
  final String matrixType = type;

  @override
  final NameChange content;

  NameChangeEvent(
      this.content, EventId id, Room room, User sender, DateTime time, UnsignedData unsigned)
      : super(id, room, sender, time, unsigned, stateKey: '');

  factory NameChangeEvent.fromJson(
      EventId id, Room room, User sender,
      DateTime time, UnsignedData unsigned, dynamic json) {
    var name = json['content']['name'];
    return NameChangeEvent(
      NameChange(name: name), id, room, sender, time, unsigned);
  }
}

class NameChange extends StateEventContent {
  @override
  final String matrixType = _nameChangeEventType;

  final String name;

  NameChange({@required this.name});

  @override
  Map<String, dynamic> toJson() => super.toJson()
    ..addAll({
      'name': name
    });
}
